/*----------------------------------------------------------------------
  PrefsPanel.c

  Copyright (C). 2003 Smoky Monkey Factory All Rights Reserved
  http://andmore.jp/mobile/

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  $Id: PrefsPanel.c,v 1.2 2003/07/29 14:55:52 zxn Exp $
  ----------------------------------------------------------------------*/

#include "PrefsPanel.h"
#include "Etc.h"
#include "Prefs.h"
#include "SnapSwitch.h"
#include "SnapSwitchRsc.h"


static prefsObj g_prefs;
static Boolean _prefsPanel_Init(prefsObj prefs);
static Boolean _prefsPanel_HandleMenu(prefsObj prefs, UInt32 menu_id);
static Boolean _prefsPanel_HandleCtl(prefsObj prefs, UInt32 ctl_id);
static Boolean _prefsPanel_HandlePop(prefsObj prefs, UInt32 pop_id);

/*---------------------------------------------------------------------
  start prefs panel
  ---------------------------------------------------------------------*/

void prefsPanel_Start(void)
{
  FrmGotoForm(MAIN_FORM_ID); /* xxx */
}

/*---------------------------------------------------------------------
  close prefs panel
  ---------------------------------------------------------------------*/

void prefsPanel_Stop(void)
{
  prefs_Save(g_prefs);
  prefs_Delete(g_prefs);
}

/*---------------------------------------------------------------------
  main form handler 
  ---------------------------------------------------------------------*/
Boolean prefsPanelEventHandler (EventPtr e)
{
    Boolean handled = false;

    switch (e->eType) 
      {
      case frmOpenEvent:
	if ((g_prefs = prefs_New()) != NULL)
	  {
	    _prefsPanel_Init(g_prefs);
	    handled = true;
	  }
	else
	  handled = false;
	break;

      case menuEvent:
	handled = _prefsPanel_HandleMenu(g_prefs, e->data.menu.itemID);
	break;

      case ctlSelectEvent:
	handled = _prefsPanel_HandleCtl(g_prefs, e->data.ctlSelect.controlID);
	break;

      case popSelectEvent:
	handled = _prefsPanel_HandlePop(g_prefs, e->data.popSelect.controlID); 
	break;

      default:
	break;
      }

    return handled;
}

/*=====================================================================
  private functions
  =====================================================================*/

/*---------------------------------------------------------------------
  init ctl objects
  ---------------------------------------------------------------------*/
static Boolean _prefsPanel_Init(prefsObj prefs)
{
  FormPtr frm;
 
  /* enabled */
  if (prefs_GetEnabled(prefs) == true)
    CtlSetValue (getObjectPtr (MAIN_BTN_ON_ID), 1);
  else
    CtlSetValue (getObjectPtr (MAIN_BTN_OFF_ID), 1);

  /* auto activate */
  CtlSetLabel(getObjectPtr (MAIN_POP_RESET_ID), 
	      LstGetSelectionText((ListPtr)getObjectPtr(MAIN_LIST_RESET_ID),
				  prefs_GetAutoActivate(prefs)));

  LstSetSelection(getObjectPtr(MAIN_LIST_RESET_ID), 
		  prefs_GetAutoActivate(prefs));

  /* draw form*/
  frm = FrmGetActiveForm();
  FrmDrawForm(frm);

  return true;
}

/*---------------------------------------------------------------------
  handle menu 
  ---------------------------------------------------------------------*/
static Boolean _prefsPanel_HandleMenu(prefsObj prefs, UInt32 menu_id)
{
  Boolean handled = true;
  FormPtr frm;

  MenuEraseStatus(NULL);

  switch(menu_id) 
    {
    case MAIN_CMD_ABOUT_ID:
      frm = FrmInitForm(ABOUT_FORM_ID);
      CtlSetLabel(FrmGetObjectPtr(frm, 
				  FrmGetObjectIndex(frm, ABOUT_LBL_VER_ID)),
		  SW_VERSION);
      FrmDoDialog(frm);
      FrmDeleteForm(frm);
      break;

#ifdef DEBUG
    case MAIN_CMD_DEBUG_ID:
      {
	prefsObj prefs;
	UInt16 card_no;
	LocalID db_id;

      if ((prefs = prefs_New()) == NULL) 
	break;

	/* switch app */
	if (prefs_GetAppInfo(prefs, &card_no, &db_id) == true) 
	  {
	    //_setNillEvent(notify_p->notifyDetailsP); 
	    prefs_GetAppInfo(prefs, &card_no, &db_id);
	    prefs_Save(prefs);
	    prefs_Delete(prefs);

	    debugMessage("card_no", "", card_no);
	    debugMessage("db_id", "", db_id);

	SysUIAppSwitch(card_no, db_id, sysAppLaunchCmdNormalLaunch, NULL);
	    
	//SndPlaySystemSound (sndInfo); /* xxx */
	return true;

	  }

	prefs_Save(prefs);
	prefs_Delete(prefs);

      break;
      }
#endif

    default:
      handled = false;
      break;
    }

  return handled;
}

/*---------------------------------------------------------------------
  handle menu 
  ---------------------------------------------------------------------*/
static Boolean _prefsPanel_HandleCtl(prefsObj prefs, UInt32 ctl_id)
{
  Boolean handled = true;

  switch(ctl_id)
    {
    case MAIN_BTN_ON_ID:
      prefs_SetEnabled(prefs, true);
      prefs_Save(prefs);
      app_enableHack();
      break;

    case MAIN_BTN_OFF_ID:
      prefs_SetEnabled(prefs, false);
      prefs_Save(prefs);
      app_disableHack();
      break;

    default:
      handled = false; 
      break;
    }

  return handled;
}

/*---------------------------------------------------------------------
  handle menu 
  ---------------------------------------------------------------------*/
static Boolean _prefsPanel_HandlePop(prefsObj prefs, UInt32 pop_id)
{
  UInt16 selection;
  Boolean handled = true;

  switch(pop_id)
    {
    case MAIN_POP_RESET_ID:
      selection = LstGetSelection(getObjectPtr(MAIN_LIST_RESET_ID));
      if (selection == noListSelection)
	selection = 0;

      prefs_SetAutoActivate(prefs, selection);

      CtlSetLabel(getObjectPtr (MAIN_POP_RESET_ID), 
		  LstGetSelectionText((ListPtr)getObjectPtr(MAIN_LIST_RESET_ID),
				  prefs_GetAutoActivate(prefs)));

      break;

    default:
      handled = false;
      break;
    }

  return handled;
}
