/*----------------------------------------------------------------------
  SnapSwitch.c -- defines structure of SnapClip

  Copyright (C). 2003 Smoky Monkey Factory All Rights Reserved
  http://andmore.jp/mobile/

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  $Id: SnapSwitch.c,v 1.2 2003/07/29 15:19:01 zxn Exp $
  ----------------------------------------------------------------------*/

#include <PalmOS.h>
#include "SnapSwitch.h"
#include "NotifyHandler.h"
#include "Prefs.h"
#include "Etc.h"

/*----------------------------------------------------------------------
  Get preferences, open (or create) app database 
  ----------------------------------------------------------------------*/
UInt16 StartApplication(void)
{
  prefsPanel_Start();
  return 0;
}

/*----------------------------------------------------------------------
  Save preferences, close forms, close app database 
  ----------------------------------------------------------------------*/
void StopApplication(void)
{
  prefsPanel_Stop();
  FrmSaveAllForms();
  FrmCloseAllForms();
}

/*----------------------------------------------------------------------
  handle application event xxx
  ----------------------------------------------------------------------*/
Boolean ApplicationHandleEvent(EventPtr e)
{
  FormPtr frm;
  UInt16 formId;
  Boolean handled = false;

  if (e->eType == frmLoadEvent) 
    {
      formId = e->data.frmLoad.formID;
      frm = FrmInitForm(formId);
      FrmSetActiveForm(frm);

      switch(formId) 
	{
	case MAIN_FORM_ID:
	  FrmSetEventHandler(frm, prefsPanelEventHandler);
	  break;
	}
      handled = true;
    }

  return handled;
}


/*---------------------------------------------------------------------
  ON
  ----------------------------------------------------------------------*/
void app_enableHack(void)
{
  UInt16 card_no;
  LocalID db_id;

  SysCurAppDatabase(&card_no, &db_id);

  /* register to notification */
  SysNotifyRegister (card_no, 
		     db_id,
		     sysNotifyEventDequeuedEvent,
		     eventDequedHandler, 
		     sysNotifyNormalPriority, 
		     NULL);

  SysNotifyRegister (card_no, 
		     db_id,
		     sysNotifyLateWakeupEvent,
		     lateWakeupEventHandler, 
		     sysNotifyNormalPriority, 
		     NULL);

#if 0
  SysNotifyRegister (card_no, 
		     db_id,
		     sysNotifyAppLaunchingEvent,
		     appLaunchingHandler, 
		     sysNotifyNormalPriority, 
		     NULL);
#endif
}

/*----------------------------------------------------------------------
  OFF
  ----------------------------------------------------------------------*/
void app_disableHack(void)
{
  UInt16 card_no;
  LocalID db_id;

  SysCurAppDatabase(&card_no, &db_id);

  /* unregister notification */
  SysNotifyUnregister(card_no, 
		      db_id,  
		      sysNotifyEventDequeuedEvent, 
		      sysNotifyNormalPriority);

  SysNotifyUnregister(card_no, 
		      db_id,  
		     sysNotifyLateWakeupEvent,
		      sysNotifyNormalPriority);

#if 0
  SysNotifyUnregister(card_no, 
		      db_id,  
		      sysNotifyAppLaunchingEvent,
		      sysNotifyNormalPriority);
#endif
}


/*----------------------------------------------------------------------
  ask activation of the hack after reset
  ----------------------------------------------------------------------*/
void app_handleReset(void) 
{
  prefsObj prefs;
  Boolean enabled = false;
  prefsAutoActivateIdx activate_idx;

  if ((prefs = prefs_New()) == NULL) 
    return;  

  activate_idx = prefs_GetAutoActivate(prefs);

  if ((activate_idx == PREFS_AUTO_ACTIVATE_YES) ||
      ((activate_idx == PREFS_AUTO_ACTIVATE_ASK) &&
       (FrmAlert(ASK_ACTIVATE_FORM_ID) ==  0)))
    {
      enabled = true;
      app_enableHack();
    }	
  else
    {
      enabled = false;
      app_disableHack();
    }

  prefs_SetEnabled(prefs, enabled);  

  prefs_Save(prefs);
  prefs_Delete(prefs);
}
